about summary refs log tree commit diff
path: root/sysdeps/unix/sysv/linux/kernel-features.h
diff options
context:
space:
mode:
authorUlrich Drepper <drepper@redhat.com>2003-07-14 21:16:43 +0000
committerUlrich Drepper <drepper@redhat.com>2003-07-14 21:16:43 +0000
commitb1b060c341b112e5face9a074e95fd366e8539bf (patch)
tree99e29cac2b00f4957a60f888c4c5605c59beb516 /sysdeps/unix/sysv/linux/kernel-features.h
parent9291eb491f78ddea7d908a58a2b2ce68c63f31ba (diff)
downloadglibc-b1b060c341b112e5face9a074e95fd366e8539bf.tar.gz
glibc-b1b060c341b112e5face9a074e95fd366e8539bf.tar.xz
glibc-b1b060c341b112e5face9a074e95fd366e8539bf.zip
Update.
2003-07-14  Ulrich Drepper  <drepper@redhat.com>

	* sysdeps/unix/sysv/linux/kernel-features.h: Define
	__ASSUME_TGKILL for Alpha appropriately.
Diffstat (limited to 'sysdeps/unix/sysv/linux/kernel-features.h')
-rw-r--r--sysdeps/unix/sysv/linux/kernel-features.h13
1 files changed, 11 insertions, 2 deletions
diff --git a/sysdeps/unix/sysv/linux/kernel-features.h b/sysdeps/unix/sysv/linux/kernel-features.h
index 3dba1de24f..e78c959529 100644
--- a/sysdeps/unix/sysv/linux/kernel-features.h
+++ b/sysdeps/unix/sysv/linux/kernel-features.h
@@ -234,6 +234,12 @@
 # define __ASSUME_NEW_PRCTL_SYSCALL		1
 #endif
 
+/* Starting with 2.4.21 the PowerPC32 clone syscall works as expected.  */
+#if __LINUX_KERNEL_VERSION >= (132096+21) && defined __powerpc__ \
+    && !defined __powerpc64__
+# define __ASSUME_FIXED_CLONE_SYSCALL		1
+#endif
+
 /* Starting with 2.4.21 PowerPC64 implements the new rt_sigreturn syscall.
    The new rt_sigreturn takes an ucontext pointer allowing rt_sigreturn
    to be used in the set/swapcontext implementation.  */
@@ -341,8 +347,11 @@
 # define __ASSUME_CORRECT_SI_PID	1
 #endif
 
-/* The tgkill syscall was instroduced for i386 in 2.5.75.  */
-#if __LINUX_KERNEL_VERSION >= 132427 && defined __i386__
+/* The tgkill syscall was instroduced for i386 in 2.5.75.  For Alpha
+   it was introduced in 2.6.0-test1 which unfortunately cannot be
+   distinguished from 2.6.0.  */
+#if (__LINUX_KERNEL_VERSION >= 132427 && defined __i386__) \
+    || (__LINUX_KERNEL_VERSION >= 132609 && defined __alpha__) \
 # define __ASSUME_TGKILL	1
 #endif